import os
from setuptools import setup, find_packages

setup(
    name="fs-comfyui-frontend-package",
    version=os.getenv("COMFYUI_FRONTEND_VERSION") or "0.20.1",
    packages=find_packages(),
    include_package_data=True,
    install_requires=[],
    python_requires=">=3.9",
    description="ComfyUI Frontend Package for web interface",
    long_description=open("README.md", "r").read(),
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
